@@ -22,7 +22,7 @@ def overview(request):
         raise Http404
 
     base_template = getattr(settings, 'PREFLIGHT_BASE_TEMPLATE',
-                            "index.1col.html")
+                            "admin/base.html")
     table_class = getattr(settings, 'PREFLIGHT_TABLE_CLASS', "listing")
 
     context = RequestContext(request, {
